Re-usable documentation
canXXXRowTemplate(canEditRow, canCloneRow, canDeleteRow)can be either of the following:
logical, e.g. TRUE or FALSE. In case of FALSE, buttons will not be visible except for new rows.
function. Needs as input an argument row which accepts a single row tibble and as output TRUE/FALSE.
can be either of the following:
logical, e.g. TRUE or FALSE. In case of FALSE, buttons will not be visible except for new rows.
function. Needs as input an argument row which accepts a single row tibble and as output TRUE/FALSE.
can be either of the following:
logical, e.g. TRUE or FALSE. In case of FALSE, buttons will not be visible except for new rows.
function. Needs as input an argument row which accepts a single row tibble and as output TRUE/FALSE.