Add some extra columns to data to allow for / keep track of modifications
initData(
data,
ns,
buttonCol = "buttons",
statusCol = "_editbl_status",
deleteCol = "_editbl_deleted",
iCol = "i",
canDeleteRow = TRUE,
canEditRow = TRUE,
canCloneRow = TRUE
)data with extra columns buttons, status, i.
data.frame
namespace function
character(1) name of column with buttons
character(1) name of column with general status (e.g. modified or not).
character(1) name of the column with deletion status.
character(1) name of column containing a unique identifier.
can be either of the following:
logical, e.g. TRUE or FALSE. In case of FALSE, buttons will not be visible except for new rows.
function. Needs as input an argument row which accepts a single row tibble and as output TRUE/FALSE.
can be either of the following:
logical, e.g. TRUE or FALSE. In case of FALSE, buttons will not be visible except for new rows.
function. Needs as input an argument row which accepts a single row tibble and as output TRUE/FALSE.
can be either of the following:
logical, e.g. TRUE or FALSE. In case of FALSE, buttons will not be visible except for new rows.
function. Needs as input an argument row which accepts a single row tibble and as output TRUE/FALSE.
Jasper Schelfhout